/**************************************************************************//**
*   @file   ad2850.h
*   @brief  Header file of AD2850 Driver for Microblaze processor.
*   @author ACozma (andrei.cozma@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 468
******************************************************************************/
#ifndef _AD2850_H_
#define _AD2850_H_

#ifdef AD2850_GLOBALS
	#define AD2850_EXT extern
#else
	#define AD2850_EXT
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "xil_types.h"
#include "xparameters.h"

/*****************************************************************************/
/* Types Declarations                                                        */
/*****************************************************************************/
typedef union _uCProbeDataUnion
{
	char 			chData;
	unsigned char 	uchData;
	short			siData;
	unsigned short	usiData;
	int 			iData;
	unsigned int 	uiData;
	float 			fData;
}uCProbeDataUnion;

typedef enum _AD2850Command
{
	NOP_CMD 				= 0x00,
	RESTORE_RDAC_CMD 		= 0x01,
	STORE_RDAC_CMD 			= 0x02,
	WRITE_EEM_CMD			= 0x03,
	DECREMENT_6dB_CMD		= 0x04,
	DECREMENT_6dB_ALL_CMD	= 0x05,
	DECREMENT_1STEP_CMD		= 0x06,
	DECREMENT_1STEP_ALL_CMD	= 0x07,
	RESET_RDACS_CMD			= 0x08,
	READ_EEM_CMD			= 0x09,
	READ_RDAC_CMD			= 0x0A,
	WRITE_RDAC_CMD			= 0x0B,
	INCREMENT_6dB_CMD		= 0x0C,
	INCREMENT_6dB_ALL_CMD	= 0x0D,
	INCREMENT_1STEP_CMD		= 0x0E,
	INCREMENT_1STEP_ALL_CMD	= 0x0F,
}AD2850Command;

#define EEM_COUNT	15

/*****************************************************************************/
/*  GPIO                                                                     */
/*****************************************************************************/
#define GPIO_RESET	(1 << 1)
#define GPIO_WP		(1 << 2)
#define GPIO_MUX_A0	(1 << 5)
#define GPIO_MUX_A1	(1 << 6)
#define GPIO_MUX_A2	(1 << 7)

/*****************************************************************************/
/* SPI Configuration                                                         */
/*****************************************************************************/
#define AD2850_SPI		XPAR_AXI_SPORT_0_BASEADDR

/*****************************************************************************/
/* Monitored variables declarations                                          */
/*****************************************************************************/
AD2850_EXT uCProbeDataUnion AD2850_Data[34];		//used to store the values for uC-Probe communication
AD2850_EXT unsigned short 	rgEemVal[EEM_COUNT];	//used to store the values from the AD2850 memory
AD2850_EXT unsigned short 	rgRdacVal[2];			//used to store the values from the RDAC wipers
AD2850_EXT unsigned char 	rgCmd[4];				//used for the C0-C3 command section switches
AD2850_EXT unsigned char 	rgCmdAddr[4];			//used for the A0-A3 command section switches
AD2850_EXT unsigned short 	rgCmdData[16];			//used for the D0-D15 command section switches

/*****************************************************************************/
/*  Functions Prototypes                                                     */
/*****************************************************************************/
int AD2850_Init(void);								//Initialize the communication with the device.
int AD2850_UpdateParameters(void);					//Update the controlled and monitored variables.
void AD2850_SendCommand(unsigned char command,
						unsigned char address,
						unsigned short* inData,
						unsigned short* outData);	//Send a command to the device.
#endif /* _AD2850_H_ */
